@@ -13,8 +13,3 @@ from ssh_proxy_server.forwarders.ssh import (
     SSHForwarder,
     SSHLogForwarder
 )
-
-from ssh_proxy_server.forwarders.sftp import (
-    SFTPBaseForwarder,
-    SFTPForwarder
-)
